pype32.pype32.DosHeader

Package pype32 :: Module pype32 :: Class DosHeader |
[hide private]
[frames] | no frames]

# Class DosHeader

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 DosHeader

DosHeader object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) Class representation of the `IMAGE_DOS_HEADER` structure. | source code
getType(self) Returns consts.IMAGE_DOS_HEADER. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
DosHeader |
parse(readDataInstance) Returns a new DosHeader object. | source code

Instance Variables | [hide private]
| e_magic WORD e_magic.
| e_cblp WORD e_cblp.
| e_cp WORD e_cp.
| e_crlc WORD e_crlc.
| e_cparhdr WORD e_cparhdr.
| e_minalloc WORD e_minalloc.
| e_maxalloc WORD e_maxalloc.
| e_ss WORD e_ss.
| e_sp WORD e_sp.
| e_csum WORD e_csum.
| e_ip WORD e_ip.
| e_cs WORD e_cs.
| e_lfarlc WORD e_lfarlc.
| e_ovno WORD e_ovno.
| e_res Array of type WORD e_res.
| e_oemid WORD e_oemid.
| e_oeminfo WORD e_oeminfo.
| e_res2 Array of type WORD e_res2.
| e_lfanew DWORD e_lfanew.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
Class representation of the `IMAGE_DOS_HEADER` structure. Parameters: `shouldPack` (bool) - (Optional) If set to `True`, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__ See Also: http://msdn.microsoft.com/en-us/magazine/cc301805.aspx

### parse(readDataInstance) Static Method | source code
Returns a new DosHeader object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a DosHeader object. Returns: DosHeader A new DosHeader object.

### getType(self) | source code
Returns consts.IMAGE_DOS_HEADER. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType